/**
 * jQuery Hover Menu.
 * Touch friendly dropdown menu.
 */
;( function($, window, document, undefined) {
	'use strict';

  var pluginName = 'hoverMenu';
  var defaults = {
    hoverClass: 'hover',
    itemsSelector: 'li',
    linksSelector: 'li > a',
  };
  var debugMode = false;

  function Plugin (element, options) {
    this.element = element;
    this.$element = $(element);
    this.settings = $.extend({}, defaults, options);
    this._defaults = defaults;
    this._name = pluginName;
    this.init();
  }

  $.extend(Plugin.prototype, {
    init: function() {
      var plugin = this;
      var $element = plugin.$element;
      var settings = plugin.settings;
      var $menuItems = $element.find(settings.itemsSelector);
      var $menuLinks = $element.find(settings.linksSelector);
      var linkLongTapTimer;

      // Emulate hover on non-touch devices
      $menuItems.on('mouseenter.hovermenu', function () {
        plugin.log('item mouseenter');
        $(this).addClass(settings.hoverClass);
      });
      $menuItems.on('mouseleave.hovermenu', function () {
        plugin.log('item mouseleave');
        $(this).removeClass(settings.hoverClass);
      });

      // Emulate hover on touch devices
      $menuItems.on('touchend.hovermenu', function (event) {
        plugin.log('item touchend');

        var $menuItem = $(this);

        if (!$menuItem.hasClass(settings.hoverClass)) {
          $menuItems.removeClass(settings.hoverClass);
          $menuItem.addClass(settings.hoverClass);
        }
        else {
          $menuItem.removeClass(settings.hoverClass);
        }
      });

      // Prevents goto link url
      $menuLinks.on('touchend.hovermenu', function (event) {
        plugin.log('link touchend');
        event.preventDefault();
        clearTimeout(linkLongTapTimer);
      });

      // Goto link url on long tap
      $menuLinks.on('touchstart.hovermenu', function () {
        plugin.log('link touchstart');

        var $menuLink = $(this);
        linkLongTapTimer = setTimeout(function () {
          window.location = $menuLink.attr('href');
        }, 400);
      });

      // Disable link context menu
      $menuLinks.on('contextmenu.hovermenu', function (event) {
        plugin.log('link contextmenu');
        event.preventDefault();
      });
    },

    log: function (message) {
      if (debugMode) {
        console.log(message);
      }
    }
  });

  $.fn[pluginName] = function(options) {
    return this.each(function() {
      if (!$.data(this, 'plugin_' + pluginName)) {
        $.data(this, 'plugin_' + pluginName, new Plugin(this, options));
      }
    });
  };

})(jQuery, window, document);
