;(function($, window, document, undefined) {

  'use strict';

  var pluginName = 'showMoreBlock';
  var defaults = {
    content: null,
    link: null,
    linkTextOpen: Drupal.t('Open'),
    linkTextClose: Drupal.t('Close'),
    minDifference: 20,
  };

  function Plugin (element, options) {
    this.element = element;
    this.settings = $.extend({}, defaults, options);
    this._defaults = defaults;
    this.init();
  }

  $.extend(Plugin.prototype, {
    init: function () {
      var plugin = this;
      var $element = $(plugin.element);
      var settings = plugin.settings;

      $element.addClass('show-more-block');

      // Process content
      if (!settings.content) {
        settings.content = $('<div class="show-more-block__content" />');
        $element.wrapInner(settings.content);
      }
      else {
        settings.content = $(settings.content);
      }
      settings.content.addClass('show-more-block__content');

      // Process link
      if (!settings.link) {
        settings.link = $('<a class="show-more-block__link" href="#">' + settings.linkTextOpen + '</a>');
        settings.link.appendTo($element);
      }
      else {
        settings.linkTextOpen = settings.link.text();
      }

      settings.link.on('click', function (event) {
        var $link = $(this);

        // Open
        if (!$element.hasClass('show-more-block--open')) {
          $element.addClass('show-more-block--open');
          $link.html(settings.linkTextClose);
        }
        // Close
        else {
          $element.removeClass('show-more-block--open');
          $link.html(settings.linkTextOpen);
        }

        event.preventDefault();
      });

      var contentMaxHeight = parseInt(settings.content.css('max-height'), 10);
      var contentRealHeight = settings.content[0].scrollHeight;
      if (contentMaxHeight + settings.minDifference >= contentRealHeight) {
        $element.addClass('show-more-block--inactive');
      }
    },
  });

  $.fn[pluginName] = function (options) {
    return this.each(function () {
      if (!$.data(this, pluginName + 'Plugin')) {
        $.data(this, pluginName + 'Plugin', new Plugin(this, options));
      }
    });
  };

})(jQuery, window, document);
