(function ($) {

  Drupal.behaviors.owlCarousel = {
    attach: function (context, settings) {
      if (context.tagName == 'SCRIPT' || !$.fn.owlCarousel) {
        return;
      }

      $('.owl-carousel', context).once('owl-carousel').each(function () {
        var $owlCarousel = $(this);
        var presetName = null;

        // Get preset name
        $.each($owlCarousel.attr('class').split(' '), function (index, className) {
          var presetMatches = className.match(/^owl-preset-(.+)$/);
          if (presetMatches) {
            presetName = $.camelCase(presetMatches[1]);
            return false;
          }
        });

        Drupal.owlCarousel($owlCarousel, presetName);
      });
    }
  };

  Drupal.owlCarousel = function (target, presetName, options) {
    var $owlCarousel = $(target);

    // Error handlers
    if (!presetName) {
      console.error('OwlCarousel preset name not found.');
      return false;
    }
    if (!Drupal.owlCarouselPresets) {
      console.error('OwlCarousel presets not exist.');
      return false;
    }
    if (!Drupal.owlCarouselPresets[presetName]) {
      console.error('OwlCarousel preset "' + presetName + '" not exist.');
      return false;
    }
    if ($owlCarousel.length == 0) {
      return false;
    }
    if ($owlCarousel.children().length <= 1) {
      return false;
    }

    if (!$owlCarousel.hasClass('owl-carousel')) {
      $owlCarousel.addClass('owl-carousel');
    }

    options = $.extend({}, Drupal.owlCarouselPresets[presetName], options);

    // Calculate margin
    if (typeof options.margin == 'string') {
      options.margin = $owlCarousel.children(':nth-child(2)').css('margin-' + options.margin);
      options.margin = parseInt(options.margin, 10);
    }

    // Wrap elements
    if (options.itemsOnSlide) {
      var itemsOnSlide = options.itemsOnSlide;
      var $owlCarouselItems = $owlCarousel.children();
      var slidesCount = Math.ceil($owlCarouselItems.length / itemsOnSlide);

      for (var slideNumber = 0; slideNumber < slidesCount; slideNumber++) {
        $owlCarouselItems.slice(slideNumber * itemsOnSlide, (slideNumber + 1) * itemsOnSlide).wrapAll('<div class="slide"></div>');
      }
    }

    $owlCarousel.owlCarousel(options);

    // Fix bug - autoplay timeout not clearing when carousel moving manualy
    var owlCarousel = $owlCarousel.data('owl.carousel');
    if (owlCarousel.options.autoplay) {
      $owlCarousel.on('translated.owl.carousel', function () {
        owlCarousel._plugins.autoplay.stop();
        owlCarousel._plugins.autoplay.play();
      });
    }
  }

})(jQuery);
